@@ -2,12 +2,13 @@ import json
 import os
 from dataclasses import dataclass, field
 from pathlib import Path
-from typing import TYPE_CHECKING, Optional
+from typing import TYPE_CHECKING
 
 from unstructured.ingest.interfaces import (
     BaseConnector,
     BaseConnectorConfig,
     BaseIngestDoc,
+    StandardConnectorConfig,
 )
 from unstructured.ingest.logger import logger
 from unstructured.utils import requires_dependencies
@@ -25,20 +26,6 @@ class SimpleRedditConfig(BaseConnectorConfig):
     search_query: str
     num_posts: int
 
-    # Standard Connector options
-    download_dir: str
-    # where to write structured data
-    output_dir: str
-    preserve_downloads: bool = False
-    re_download: bool = False
-    download_only: bool = False
-    metadata_include: Optional[str] = None
-    metadata_exclude: Optional[str] = None
-    partition_by_api: bool = False
-    partition_endpoint: str = "https://api.unstructured.io/general/v0/general"
-    fields_include: str = "element_id,text,type,metadata"
-    flatten_metadata: bool = False
-
     def __post_init__(self):
         if self.num_posts <= 0:
             raise ValueError("The number of Reddit posts to fetch must be positive.")
@@ -51,24 +38,28 @@ class RedditIngestDoc(BaseIngestDoc):
 
     @property
     def filename(self) -> Path:
-        return (Path(self.config.download_dir) / f"{self.post.id}.md").resolve()
+        return (Path(self.standard_config.download_dir) / f"{self.post.id}.md").resolve()
 
     def _output_filename(self):
-        return Path(self.config.output_dir) / f"{self.post.id}.json"
+        return Path(self.standard_config.output_dir) / f"{self.post.id}.json"
 
     def _create_full_tmp_dir_path(self):
         self.filename.parent.mkdir(parents=True, exist_ok=True)
 
     def cleanup_file(self):
         """Removes the local copy of the file (or anything else) after successful processing."""
-        if not self.config.preserve_downloads and not self.config.download_only:
+        if not self.standard_config.preserve_downloads and not self.standard_config.download_only:
             logger.debug(f"Cleaning up {self}")
             os.unlink(self.filename)
 
     def get_file(self):
         """Fetches the "remote" doc and stores it locally on the filesystem."""
         self._create_full_tmp_dir_path()
-        if not self.config.re_download and self.filename.is_file() and self.filename.stat():
+        if (
+            not self.standard_config.re_download
+            and self.filename.is_file()
+            and self.filename.stat()
+        ):
             logger.debug(f"File exists: {self.filename}, skipping download")
             return
 
@@ -85,7 +76,7 @@ class RedditIngestDoc(BaseIngestDoc):
 
     def write_result(self):
         """Write the structured json result for this doc. result must be json serializable."""
-        if self.config.download_only:
+        if self.standard_config.download_only:
             return
         output_filename = self._output_filename()
         output_filename.parent.mkdir(parents=True, exist_ok=True)
@@ -96,23 +87,27 @@ class RedditIngestDoc(BaseIngestDoc):
 
 @requires_dependencies(["praw"], extras="reddit")
 class RedditConnector(BaseConnector):
-    def __init__(self, config: SimpleRedditConfig):
+    config: SimpleRedditConfig
+
+    def __init__(self, standard_config: StandardConnectorConfig, config: SimpleRedditConfig):
         from praw import Reddit
 
-        self.config = config
+        super().__init__(standard_config, config)
         self.reddit = Reddit(
             client_id=config.client_id,
             client_secret=config.client_secret,
             user_agent=config.user_agent,
         )
-        self.cleanup_files = not config.preserve_downloads and not config.download_only
+        self.cleanup_files = (
+            not standard_config.preserve_downloads and not standard_config.download_only
+        )
 
     def cleanup(self, cur_dir=None):
         if not self.cleanup_files:
             return
 
         if cur_dir is None:
-            cur_dir = self.config.download_dir
+            cur_dir = self.standard_config.download_dir
         sub_dirs = os.listdir(cur_dir)
         os.chdir(cur_dir)
         for sub_dir in sub_dirs:
@@ -132,4 +127,4 @@ class RedditConnector(BaseConnector):
             posts = subreddit.search(self.config.search_query, limit=self.config.num_posts)
         else:
             posts = subreddit.hot(limit=self.config.num_posts)
-        return [RedditIngestDoc(self.config, post) for post in posts]
+        return [RedditIngestDoc(self.standard_config, self.config, post) for post in posts]
