@@ -6,6 +6,7 @@ from email.message import Message
 from functools import partial
 from typing import IO, Dict, List, Optional, Tuple, Union
 
+from unstructured.file_utils.encoding import read_txt_file
 from unstructured.partition.common import exactly_one
 
 if sys.version_info < (3, 8):
@@ -28,6 +29,7 @@ from unstructured.documents.elements import (
     NarrativeText,
     Text,
     Title,
+    process_metadata,
 )
 from unstructured.documents.email_elements import (
     MetaData,
@@ -36,6 +38,7 @@ from unstructured.documents.email_elements import (
     Sender,
     Subject,
 )
+from unstructured.file_utils.filetype import FileType, add_metadata_with_filetype
 from unstructured.logger import logger
 from unstructured.nlp.patterns import EMAIL_DATETIMETZ_PATTERN_RE
 from unstructured.partition.html import partition_html
@@ -180,6 +183,8 @@ def find_embedded_image(
     return Image(text=image_info[:-1]), element
 
 
+@process_metadata()
+@add_metadata_with_filetype(FileType.EML)
 def partition_email(
     filename: Optional[str] = None,
     file: Optional[IO] = None,
@@ -187,6 +192,7 @@ def partition_email(
     content_source: str = "text/html",
     encoding: Optional[str] = None,
     include_headers: bool = False,
+    **kwargs,
 ) -> List[Element]:
     """Partitions an .eml documents into its constituent elements.
     Parameters
@@ -203,9 +209,6 @@ def partition_email(
     encoding
         The encoding method used to decode the text input. If None, utf-8 will be used.
     """
-    if not encoding:
-        encoding = "utf-8"
-
     if content_source not in VALID_CONTENT_SOURCES:
         raise ValueError(
             f"{content_source} is not a valid value for content_source. "
@@ -219,16 +222,11 @@ def partition_email(
     exactly_one(filename=filename, file=file, text=text)
 
     if filename is not None:
-        with open(filename) as f:
-            msg = email.message_from_file(f)
+        encoding, file_text = read_txt_file(filename=filename, encoding=encoding)
+        msg = email.message_from_string(file_text)
 
     elif file is not None:
-        file_content = file.read()
-        if isinstance(file_content, bytes):
-            file_text = file_content.decode(encoding)
-        else:
-            file_text = file_content
-
+        encoding, file_text = read_txt_file(file=file, encoding=encoding)
         msg = email.message_from_string(file_text)
 
     elif text is not None:
@@ -256,13 +254,19 @@ def partition_email(
         #    <li>Item 1</li>=
         #    <li>Item 2<li>=
         # </ul>
+        if not encoding:
+            encoding = "utf-8"
         list_content = content.split("=\n")
         content = "".join(list_content)
         elements = partition_html(text=content, include_metadata=False)
         for element in elements:
             if isinstance(element, Text):
                 _replace_mime_encodings = partial(replace_mime_encodings, encoding=encoding)
-                element.apply(_replace_mime_encodings)
+                try:
+                    element.apply(_replace_mime_encodings)
+                except UnicodeDecodeError:
+                    # If decoding fails, try decoding with default encoding (utf-8)
+                    element.apply(replace_mime_encodings)
     elif content_source == "text/plain":
         list_content = split_by_paragraph(content)
         elements = partition_text(text=content)
