@@ -2,17 +2,23 @@ from typing import IO, Dict, List, Optional
 
 import requests
 
-from unstructured.documents.elements import Element
+from unstructured.documents.elements import Element, process_metadata
 from unstructured.documents.html import HTMLDocument
 from unstructured.documents.xml import VALID_PARSERS
+from unstructured.file_utils.encoding import read_txt_file
 from unstructured.file_utils.file_conversion import convert_file_to_html_text
-from unstructured.partition.common import (
-    add_element_metadata,
+from unstructured.file_utils.filetype import (
+    FileType,
+    add_metadata_with_filetype,
     document_to_element_list,
+)
+from unstructured.partition.common import (
     exactly_one,
 )
 
 
+@process_metadata()
+@add_metadata_with_filetype(FileType.HTML)
 def partition_html(
     filename: Optional[str] = None,
     file: Optional[IO] = None,
@@ -24,6 +30,7 @@ def partition_html(
     headers: Dict[str, str] = {},
     ssl_verify: bool = True,
     parser: VALID_PARSERS = None,
+    **kwargs,
 ) -> List[Element]:
     """Partitions an HTML document into its constituent elements.
 
@@ -58,19 +65,11 @@ def partition_html(
     # Verify that only one of the arguments was provided
     exactly_one(filename=filename, file=file, text=text, url=url)
 
-    if not encoding:
-        encoding = "utf-8"
-
     if filename is not None:
         document = HTMLDocument.from_file(filename, parser=parser, encoding=encoding)
 
     elif file is not None:
-        file_content = file.read()
-        if isinstance(file_content, bytes):
-            file_text = file_content.decode(encoding)
-        else:
-            file_text = file_content
-
+        _, file_text = read_txt_file(file=file, encoding=encoding)
         document = HTMLDocument.from_string(file_text, parser=parser)
 
     elif text is not None:
@@ -88,16 +87,7 @@ def partition_html(
 
         document = HTMLDocument.from_string(response.text, parser=parser)
 
-    layout_elements = document_to_element_list(document, include_page_breaks=include_page_breaks)
-    if include_metadata:
-        return add_element_metadata(
-            layout_elements,
-            include_page_breaks=include_page_breaks,
-            filename=filename,
-            url=url,
-        )
-    else:
-        return layout_elements
+    return document_to_element_list(document, include_page_breaks=include_page_breaks)
 
 
 def convert_and_partition_html(
