@@ -9,10 +9,17 @@ from unstructured.documents.elements import (
     ListItem,
     NarrativeText,
     PageBreak,
+    Table,
     Text,
     Title,
+    process_metadata,
+)
+from unstructured.file_utils.filetype import FileType, add_metadata_with_filetype
+from unstructured.partition.common import (
+    convert_ms_office_table_to_text,
+    exactly_one,
+    spooled_to_bytes_io_if_needed,
 )
-from unstructured.partition.common import exactly_one, spooled_to_bytes_io_if_needed
 from unstructured.partition.text_type import (
     is_possible_narrative_text,
     is_possible_title,
@@ -21,11 +28,14 @@ from unstructured.partition.text_type import (
 OPENXML_SCHEMA_NAME = "{http://schemas.openxmlformats.org/drawingml/2006/main}"
 
 
+@process_metadata()
+@add_metadata_with_filetype(FileType.PPTX)
 def partition_pptx(
     filename: Optional[str] = None,
     file: Optional[Union[IO, SpooledTemporaryFile]] = None,
     include_page_breaks: bool = True,
     metadata_filename: Optional[str] = None,
+    **kwargs,
 ) -> List[Element]:
     """Partitions Microsoft PowerPoint Documents in .pptx format into its document elements.
 
@@ -58,17 +68,27 @@ def partition_pptx(
     metadata = ElementMetadata(filename=metadata_filename)
     num_slides = len(presentation.slides)
     for i, slide in enumerate(presentation.slides):
+        metadata = ElementMetadata(**metadata.to_dict())
         metadata.page_number = i + 1
 
         for shape in _order_shapes(slide.shapes):
-            # NOTE(robinson) - we don't deal with tables yet, but so future humans can find
-            # it again, here are docs on how to deal with tables. The check for tables should
-            # be `if shape.has_table`
-            # ref: https://python-pptx.readthedocs.io/en/latest/user/table.html#adding-a-table
+            if shape.has_table:
+                table: pptx.table.Table = shape.table
+                html_table = convert_ms_office_table_to_text(table, as_html=True)
+                text_table = convert_ms_office_table_to_text(table, as_html=False)
+                if (text_table := text_table.strip()) != "":
+                    metadata = ElementMetadata(
+                        filename=metadata_filename,
+                        text_as_html=html_table,
+                        page_number=metadata.page_number,
+                    )
+                    elements.append(Table(text=text_table, metadata=metadata))
+                continue
             if not shape.has_text_frame:
                 continue
             # NOTE(robinson) - avoid processing shapes that are not on the actual slide
-            if shape.top < 0 or shape.left < 0:
+            # NOTE - skip check if no top or left position (shape displayed top left)
+            if (shape.top and shape.left) and (shape.top < 0 or shape.left < 0):
                 continue
             for paragraph in shape.text_frame.paragraphs:
                 text = paragraph.text
@@ -91,7 +111,7 @@ def partition_pptx(
 
 def _order_shapes(shapes):
     """Orders the shapes from top to bottom and left to right."""
-    return sorted(shapes, key=lambda x: (x.top, x.left))
+    return sorted(shapes, key=lambda x: (x.top or 0, x.left or 0))
 
 
 def _is_bulleted_paragraph(paragraph) -> bool:
